@@ -1,4 +1,4 @@
-# Copyright 1995,2000 Spider Boardman.
+# Copyright 1995,2002 Spider Boardman.
 # All rights reserved.
 #
 # Automatic licensing for this software is available.  This software
@@ -11,7 +11,7 @@
 # IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 # WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
-# rcsid: "@(#) $Id: TCP.dat,v 1.24 2000/08/05 20:33:14 spider Exp $"
+# rcsid: "@(#) $Id: TCP.dat,v 1.25 2002/03/30 10:11:53 spider Exp $"
 
 package Net::TCP;
 use 5.004_04;			# new minimum Perl version for this package
@@ -23,14 +23,14 @@ sub croak { require Carp; goto &Carp::croak; }
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS *AUTOLOAD);
 
 BEGIN {
-    $VERSION = '0.933';
+    $VERSION = '1.0';
     eval "sub Version () { __PACKAGE__ . ' v$VERSION' }";
 }
 
 #use AutoLoader;	# disable this until we have autoloadable subs again
 #use Exporter ();	# we inherit what we need here from Net::Gen
-use Net::Inet 0.93;
-use Net::Gen 0.93 ':sockvals', ':families';
+use Net::Inet 1.0;
+use Net::Gen 1.0 ':sockvals', ':families';
 
 BEGIN {
     @ISA = 'Net::Inet';
@@ -108,9 +108,8 @@ __PACKAGE__->initsockopts( IPPROTO_TCP, \%sockopts );
 my $debug = 0;
 
 #& _debug($this, [$newval]) : oldval
-sub _debug
+sub _debug : locked
 {
-    use attrs qw(locked);
     my ($this,$newval) = @_;
     return $this->debug($newval) if ref $this;
     my $prev = $debug;
@@ -120,9 +119,8 @@ sub _debug
 
 my %Sopts;			# do a full register_options only once
 
-sub new
+sub new : locked
 {
-    use attrs qw(locked);
     my $whoami = $_[0]->_trace(\@_,1);
     my($class,@args) = @_;
     my $self = $class->SUPER::new(@args);
@@ -233,7 +231,7 @@ The examples above show the indirect object syntax which many prefer,
 as well as the guaranteed-to-be-safe static method call.  There
 are occasional problems with the indirect object syntax, which
 tend to be rather obscure when encountered.  See
-http://www.rosat.mpe-garching.mpg.de/mailing-lists/perl-porters/1998-01/msg01674.html
+http://www.xray.mpe.mpg.de/mailing-lists/perl5-porters/1998-01/msg01674.html
 for details.
 
 =back
@@ -331,7 +329,8 @@ Z<>
 
 This module has been tested with threaded perls, and should be as thread-safe
 as perl itself.  (As of 5.005_03 and 5.005_57, that's not all that safe
-just yet.)
+just yet.)  It also works with interpreter-based threads ('ithreads') in
+more recent perl releases.
 
 =head1 SEE ALSO
 
@@ -341,7 +340,7 @@ L<Net::TCP::Server(3)|Net::TCP::Server>
 
 =head1 AUTHOR
 
-Spider Boardman E<lt>spider@Orb.Nashua.NH.USE<gt>
+Spider Boardman E<lt>spidb@cpan.orgE<gt>
 
 =cut
 
