@@ -1,4 +1,4 @@
-# Copyright 1995,2000 Spider Boardman.
+# Copyright 1995,2002 Spider Boardman.
 # All rights reserved.
 #
 # Automatic licensing for this software is available.  This software
@@ -11,7 +11,7 @@
 # IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 # WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
-# rcsid: "@(#) $Id: UDP.dat,v 1.20 2000/08/05 20:33:14 spider Exp $"
+# rcsid: "@(#) $Id: UDP.dat,v 1.21 2002/03/30 10:10:55 spider Exp $"
 
 package Net::UDP;
 use 5.004_04;			# new minimum Perl version for this package
@@ -23,14 +23,14 @@ sub croak { require Carp; goto &Carp::croak; }
 use vars qw($VERSION @ISA *AUTOLOAD);
 
 BEGIN {
-    $VERSION = '0.933';
+    $VERSION = '1.0';
     eval "sub Version () { __PACKAGE__ . ' v$VERSION' }";
 }
 
 use AutoLoader;
 
-use Net::Inet 0.93;
-use Net::Gen 0.93 ':sockvals', ':families';
+use Net::Inet 1.0;
+use Net::Gen 1.0 ':sockvals', ':families';
 
 BEGIN {
     @ISA = 'Net::Inet';
@@ -58,9 +58,8 @@ my %CodeKeys;
 
 my %Keys;			# for only calling registration routines once
 
-sub new
+sub new : locked
 {
-    use attrs qw(locked);
     my($class,@args) = @_;
     my $self = $class->SUPER::new(@args);
     $class = ref $class if ref $class;
@@ -172,7 +171,7 @@ The examples above show the indirect object syntax which many prefer,
 as well as the guaranteed-to-be-safe static method call.  There
 are occasional problems with the indirect object syntax, which
 tend to be rather obscure when encountered.  See
-http://www.rosat.mpe-garching.mpg.de/mailing-lists/perl-porters/1998-01/msg01674.html
+http://www.xray.mpe.mpg.de/mailing-lists/perl5-porters/1998-01/msg01674.html
 for details.
 
 =item PRINT
@@ -323,7 +322,8 @@ none
 
 This module has been tested with threaded perls, and should be as thread-safe
 as perl itself.  (As of 5.005_03 and 5.005_57, that's not all that safe
-just yet.)
+just yet.)  It also works with interpreter-based threads ('ithreads') in
+more recent perl releases.
 
 =head1 SEE ALSO
 
@@ -332,7 +332,7 @@ L<Net::Gen(3)|Net::Gen>
 
 =head1 AUTHOR
 
-Spider Boardman E<lt>spider@Orb.Nashua.NH.USE<gt>
+Spider Boardman E<lt>spidb@cpan.orgE<gt>
 
 =cut
 
@@ -350,9 +350,8 @@ sub _setbuf_unbuf
 }
 
 #& PRINT($self, @args) : OKness
-sub PRINT
+sub PRINT : locked method
 {
-    use attrs qw(locked method);
     my $self = shift;
     if ($self->getparam('unbuffered_output')) {
 	$self->send(join $, , @_);
@@ -363,9 +362,8 @@ sub PRINT
 }
 
 #& READLINE($self) : $line | undef || @lines
-sub READLINE
+sub READLINE : locked method
 {
-    use attrs qw(locked method);
     my $whoami = $_[0]->_trace(\@_,5);
     carp "Excess arguments to ${whoami}, ignored" if @_ > 1;
     my $self = shift;
